==> ssp-center-api-0.7.23-20200608.102435-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteWeChatDomainService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.*;

import java.util.List;

/**
 * 微信小程序域名服务
 */
@AdvancedFeignClient
public interface RemoteWeChatDomainService {

    /**
     * 查询域名列表
     * @param weChatDomainReq
     * @return
     */
    List<WeChatDomainItemRsp> queryDomainList(WeChatDomainReq weChatDomainReq);

    /**
     * 条目数
     * @param weChatDomainReq
     * @return
     */
    int countDomainList(WeChatDomainReq weChatDomainReq);

    /**
     * 查询代理域名列表
     * @param weChatProxyDomainReq
     * @return
     */
    List<WeChatProxyDomainItemRsp> qyeryProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 条目数
     * @param weChatProxyDomainReq
     * @return
     */
    int countProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 添加域名
     * @param weChatDomainReq
     * @return
     */
    int saveDomainList(WeChatDomainReq weChatDomainReq) throws BizException;

    /**
     * 添加代理域名
     * @param weChatProxyDomainReq
     * @return
     */
    int saveProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 修改域名
     * @param weChatDomainReq
     * @return
     */
    int modifyDomainList(WeChatDomainReq weChatDomainReq) throws BizException;

    /**
     * 修改代理域名
     * @param weChatProxyDomainReq
     * @return
     */
    int modifyProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 删除域名
     * @param weChatDomainReq
     * @return
     */
    int removeDomainList(WeChatDomainReq weChatDomainReq);

    /**
     * 删除代理域名
     * @param weChatProxyDomainReq
     * @return
     */
    int removeProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 微信广告位域名列表
     * @return
     */
    List<WeChatSlotDomainRsp> querySlotDomainList();

    /**
     * 添加微信域名广告位
     * @param weChatSlotDomainReq
     * @return
     */
    int saveSlotDomainList(WeChatSlotDomainReq weChatSlotDomainReq);

    /**
     * 查询广告位下的域名 随机取一个
     * @param reverseProxyInfoReq
     * @return
     */
    WeChatSlotDomainDto getReverseProxyInfo(ReverseProxyInfoReq reverseProxyInfoReq);

    /**
     * 删除域名广告位
     * @param weChatSlotDomainReq
     * @return
     */
    int removeSlotDomainItem(WeChatSlotDomainReq weChatSlotDomainReq);

    /**
     * 修改域名广告位
     * @param weChatProxyDomainReq
     * @return
     */
    int modifyProxyDomainItem(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 查询告警列表
     * @return
     */
    List<WeChatDomainAlarmDto> queryAlarmList();

    /**
     * 保存告警信息
     * @param weChatDomainAlarmReq
     * @return
     */
    int saveAlarmList(WeChatDomainAlarmReq weChatDomainAlarmReq);
}

==> ssp-center-api-0.8.63-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteWeChatDomainService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.*;

import java.util.List;

/**
 * 微信小程序域名服务
 */
@AdvancedFeignClient
public interface RemoteWeChatDomainService {

    /**
     * 查询域名列表
     * @param weChatDomainReq
     * @return
     */
    List<WeChatDomainItemRsp> queryDomainList(WeChatDomainReq weChatDomainReq);

    /**
     * 条目数
     * @param weChatDomainReq
     * @return
     */
    int countDomainList(WeChatDomainReq weChatDomainReq);

    /**
     * 查询代理域名列表
     * @param weChatProxyDomainReq
     * @return
     */
    List<WeChatProxyDomainItemRsp> qyeryProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 条目数
     * @param weChatProxyDomainReq
     * @return
     */
    int countProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 添加域名
     * @param weChatDomainReq
     * @return
     */
    int saveDomainList(WeChatDomainReq weChatDomainReq) throws BizException;

    /**
     * 添加代理域名
     * @param weChatProxyDomainReq
     * @return
     */
    int saveProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 修改域名
     * @param weChatDomainReq
     * @return
     */
    int modifyDomainList(WeChatDomainReq weChatDomainReq) throws BizException;

    /**
     * 修改代理域名
     * @param weChatProxyDomainReq
     * @return
     */
    int modifyProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 删除域名
     * @param weChatDomainReq
     * @return
     */
    int removeDomainList(WeChatDomainReq weChatDomainReq);

    /**
     * 删除代理域名
     * @param weChatProxyDomainReq
     * @return
     */
    int removeProxyDomainList(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 微信广告位域名列表
     * @return
     */
    List<WeChatSlotDomainRsp> querySlotDomainList();

    /**
     * 添加微信域名广告位
     * @param weChatSlotDomainReqList
     * @return
     */
    int saveSlotDomainList(List<WeChatSlotDomainReq> weChatSlotDomainReqList);

    /**
     * 查询广告位下的域名 随机取一个
     * @param reverseProxyInfoReq
     * @return
     */
    WeChatSlotDomainDto getReverseProxyInfo(ReverseProxyInfoReq reverseProxyInfoReq);

    /**
     * 删除域名广告位
     * @param weChatSlotDomainReq
     * @return
     */
    int removeSlotDomainItem(WeChatSlotDomainReq weChatSlotDomainReq);

    /**
     * 修改域名广告位
     * @param weChatProxyDomainReq
     * @return
     */
    int modifyProxyDomainItem(WeChatProxyDomainReq weChatProxyDomainReq);

    /**
     * 查询告警列表
     * @return
     */
    List<WeChatDomainAlarmDto> queryAlarmList();

    /**
     * 保存告警信息
     * @param weChatDomainAlarmReq
     * @return
     */
    int saveAlarmList(WeChatDomainAlarmReq weChatDomainAlarmReq);

    /**
     * 获取域名巡检列表
     * @return
     */
    List<WeChatDomainInspectRsp> getDomainInspectList();

    /**
     * 域名巡检回调
     * @param weChatDomainInspectReq
     */
    void domainInspectCallBack(WeChatDomainInspectReq weChatDomainInspectReq);

    /**
     * 查询代理域名列表
     * @return
     */
    List<WeChatProxyDomainItemRsp> getProxyDomainList();

    /**
     * 根据广告位id查询域名列表
     * @param slotId
     * @return
     */
    List<WeChatSlotDomainRsp> querySlotDomainListBySlotId(Long slotId);

    /**
     * 删除广告位
     * @param slotId
     * @return
     */
    int removeWeChatSlot(Long slotId);

    /**
     * 广告位分页查询
     * @param weChatSlotReq
     * @return
     */
    List<WeChatSlotItemRsp> querySlotList(WeChatSlotReq weChatSlotReq);

    /**
     * 广告位counnt
     * @param weChatSlotReq
     * @return
     */
    int countSlotList(WeChatSlotReq weChatSlotReq);

    /**
     * 查询导出数据
     * @param weChatSlotReq
     * @return
     */
    List<WeChatSlotItemRsp> exportSlotData(WeChatSlotReq weChatSlotReq);

    /**
     * 根据广告位ID查询域名列表
     * @param slotId
     * @return
     */
    List<WeChatSlotDomainItemRsp> getSlotDomainList(Long slotId);

    /**
     * 添加广告位
     * @param weChatSlotSaveReq
     * @return
     */
    int saveSlotInfo(WeChatSlotSaveReq weChatSlotSaveReq) throws BizException;

    /**
     * 修改广告位域名列表
     * @param weChatSlotSaveReq
     * @return
     */
    int modifySlotInfo(WeChatSlotSaveReq weChatSlotSaveReq);

    /**
     * 获取微信小程序广告位列表
     * @return
     */
    List<Long> getWeChatSoltList();

    /**
     * 初始化数据
     * @return
     */
    int initSlotData(List<WeChatSlotSaveReq> weChatSlotSaveReqList);
}
